summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorConstantine A. Murenin <cnst@cvs.openbsd.org>2007-05-26 22:47:40 +0000
committerConstantine A. Murenin <cnst@cvs.openbsd.org>2007-05-26 22:47:40 +0000
commit1b307b2f0593fc9aa5ab4f28cf754c715479efc1 (patch)
tree090b77b4cf0629cfdac45158e2f306e361b04377
parent5552f78a702dfee3761ae44423777e5c3f90524d (diff)
fix a copy/paste typo from my previous commit: s/dhf/dhg/g
-rw-r--r--sys/dev/ic/lm78.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/sys/dev/ic/lm78.c b/sys/dev/ic/lm78.c
index b7b2b37d73f..b55567be46e 100644
--- a/sys/dev/ic/lm78.c
+++ b/sys/dev/ic/lm78.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: lm78.c,v 1.17 2007/05/25 02:26:43 cnst Exp $ */
+/* $OpenBSD: lm78.c,v 1.18 2007/05/26 22:47:39 cnst Exp $ */
/*
* Copyright (c) 2005, 2006 Mark Kettenis
@@ -159,10 +159,10 @@ struct lm_sensor w83627ehf_sensors[] = {
};
/*
* w83627dhf is almost identical to w83627ehf, except that
* it has 9 instead of 10 voltage sensors
*/
-struct lm_sensor w83627dhf_sensors[] = {
+struct lm_sensor w83627dhg_sensors[] = {
/* Voltage */
{ "VCore", SENSOR_VOLTS_DC, 0, 0x20, lm_refresh_volt, RFACT_NONE / 2},
{ "+12V", SENSOR_VOLTS_DC, 0, 0x21, lm_refresh_volt, RFACT(56, 10) / 2 },
@@ -508,8 +508,8 @@ wb_match(struct lm_softc *sc)
lm_setup_sensors(sc, w83627ehf_sensors);
break;
case WB_CHIPID_W83627DHG:
- printf(": W83627DHF\n");
- lm_setup_sensors(sc, w83627dhf_sensors);
+ printf(": W83627DHG\n");
+ lm_setup_sensors(sc, w83627dhg_sensors);
break;
case WB_CHIPID_W83637HF:
printf(": W83637HF\n");
@@ -159,10 +159,10 @@ struct lm_sensor w83627ehf_sensors[] = {
};
/*
- * w83627dhf is almost identical to w83627ehf, except that
+ * w83627dhg is almost identical to w83627ehf, except that
* it has 9 instead of 10 voltage sensors
*/